"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.renderRichText = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _lodash = require("lodash");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _gatsby = require("gatsby");

var _Card = _interopRequireDefault(require("@material-ui/core/Card"));

var _CardContent = _interopRequireDefault(require("@material-ui/core/CardContent"));

var _Box = _interopRequireDefault(require("@material-ui/core/Box"));

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

var _List = _interopRequireDefault(require("@material-ui/core/List"));

var _ListItem = _interopRequireDefault(require("@material-ui/core/ListItem"));

var _CardActionArea = _interopRequireDefault(require("@material-ui/core/CardActionArea"));

var _ListItemIcon = _interopRequireDefault(require("@material-ui/core/ListItemIcon"));

var _Divider = _interopRequireDefault(require("@material-ui/core/Divider"));

var _CheckCircle = _interopRequireDefault(require("@material-ui/icons/CheckCircle"));

var _richTextReactRenderer = require("@contentful/rich-text-react-renderer");

var _richTextTypes = require("@contentful/rich-text-types");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isImage = v => v === 'image';

const getGroup = v => typeof v === 'string' ? v.split('/')[0] : '';

const imageRender = (node, locale) => {
  const {
    title,
    description,
    file
  } = (0, _lodash.get)(node, 'data.target.fields', {});
  if (!file || !(locale in file)) return null;
  const mimeType = file[locale].contentType;
  const mimeGroup = getGroup(mimeType);
  return isImage(mimeGroup) ? /*#__PURE__*/_react.default.createElement("img", {
    title: title ? title[locale] : null,
    alt: description ? description[locale] : null,
    src: file[locale].url
  }) : null;
};

const renderRichText = (json, locale = 'en-CA', sitemap = {}) => {
  if (!json || !Object.keys(json).length) return null;

  const getFromSitemap = node => (0, _lodash.get)(sitemap, (0, _lodash.get)(node, 'data.target.sys.contentful_id'));

  return (0, _richTextReactRenderer.documentToReactComponents)(json, {
    renderMark: {
      [_richTextTypes.MARKS.BOLD]: text => /*#__PURE__*/_react.default.createElement("strong", null, text),
      [_richTextTypes.MARKS.ITALIC]: text => /*#__PURE__*/_react.default.createElement("i", null, text),
      [_richTextTypes.MARKS.UNDERLINE]: text => /*#__PURE__*/_react.default.createElement("u", null, text),
      [_richTextTypes.MARKS.CODE]: text => /*#__PURE__*/_react.default.createElement("code", null, text)
    },
    renderNode: {
      [_richTextTypes.BLOCKS.PARAGRAPH]: (node, children) => /*#__PURE__*/_react.default.createElement(_Typography.default, {
        component: "p"
      }, children),
      [_richTextTypes.BLOCKS.HEADING_1]: (node, children) => /*#__PURE__*/_react.default.createElement(_Typography.default, {
        variant: "h1",
        gutterBottom: true
      }, children),
      [_richTextTypes.BLOCKS.HEADING_2]: (node, children) => /*#__PURE__*/_react.default.createElement(_Typography.default, {
        variant: "h2",
        gutterBottom: true
      }, children),
      [_richTextTypes.BLOCKS.HEADING_3]: (node, children) => /*#__PURE__*/_react.default.createElement(_Typography.default, {
        variant: "h3",
        gutterBottom: true
      }, children),
      [_richTextTypes.BLOCKS.HEADING_4]: (node, children) => /*#__PURE__*/_react.default.createElement(_Typography.default, {
        variant: "h4",
        gutterBottom: true
      }, children),
      [_richTextTypes.BLOCKS.HEADING_5]: (node, children) => /*#__PURE__*/_react.default.createElement(_Typography.default, {
        variant: "h5",
        gutterBottom: true
      }, children),
      [_richTextTypes.BLOCKS.HEADING_6]: (node, children) => /*#__PURE__*/_react.default.createElement(_Typography.default, {
        variant: "h6",
        gutterBottom: true
      }, children),
      [_richTextTypes.BLOCKS.OL_LIST]: (node, children) => /*#__PURE__*/_react.default.createElement(_List.default, {
        component: "ol"
      }, children),
      [_richTextTypes.BLOCKS.UL_LIST]: (node, children) => /*#__PURE__*/_react.default.createElement(_List.default, {
        component: "ul"
      }, children),
      [_richTextTypes.BLOCKS.LIST_ITEM]: (node, children) => /*#__PURE__*/_react.default.createElement(_ListItem.default, null, /*#__PURE__*/_react.default.createElement(_ListItemIcon.default, null, /*#__PURE__*/_react.default.createElement(_CheckCircle.default, null)), children),
      [_richTextTypes.BLOCKS.HR]: () => /*#__PURE__*/_react.default.createElement(_Divider.default, null),
      [_richTextTypes.BLOCKS.QUOTE]: (node, children) => /*#__PURE__*/_react.default.createElement("blockquote", null, children),
      [_richTextTypes.BLOCKS.EMBEDDED_ASSET]: node => imageRender(node, locale),
      [_richTextTypes.BLOCKS.EMBEDDED_ENTRY]: () => null,
      [_richTextTypes.INLINES.EMBEDDED_ENTRY]: node => {
        const path = getFromSitemap(node);
        return path ? /*#__PURE__*/_react.default.createElement(_Box.default, {
          my: 2
        }, /*#__PURE__*/_react.default.createElement(_Card.default, {
          component: "aside"
        }, /*#__PURE__*/_react.default.createElement(_CardActionArea.default, {
          component: _gatsby.Link,
          to: path
        }, /*#__PURE__*/_react.default.createElement(_CardContent.default, null, /*#__PURE__*/_react.default.createElement(_Box.default, {
          p: 2
        }, /*#__PURE__*/_react.default.createElement(_Typography.default, {
          variant: "body2",
          component: "h3",
          gutterBottom: true
        }, (0, _lodash.get)(node, `data.target.fields.title.${locale}`)), /*#__PURE__*/_react.default.createElement(_Typography.default, {
          component: "small"
        }, (0, _lodash.get)(node, `data.target.fields.description.${locale}`))))))) : null;
      }
    }
  });
};

exports.renderRichText = renderRichText;

const RichText = ({
  json,
  locale
}) => {
  const data = (0, _gatsby.useStaticQuery)((0, _gatsby.graphql)`
    {
      allSitePage {
        nodes {
          path
          pageContext
        }
      }
    }
  `);
  return /*#__PURE__*/_react.default.createElement("div", null, renderRichText(json, locale, data.allSitePage.nodes.reduce((acc, next, i) => {
    acc[(0, _lodash.get)(next, 'pageContext.contentful_id', i)] = next.path;
    return acc;
  }, {})));
};

RichText.propTypes = {
  // eslint-disable-next-line
  json: _propTypes.default.object,
  locale: _propTypes.default.string
};
RichText.defaultProps = {
  locale: 'en-CA'
};
var _default = RichText;
exports.default = _default;